@@ -38,19 +38,19 @@
  ***************************************************************************/
 
 /** The library version (string) e.g. "1.3.0" */
-#define UPNP_VERSION_STRING "17.8.1"
+#define UPNP_VERSION_STRING "17.1.4"
 
 /** Major version of the library */
 #define UPNP_VERSION_MAJOR 17
 
 /** Minor version of the library */
-#define UPNP_VERSION_MINOR 8
+#define UPNP_VERSION_MINOR 1
 #ifndef UPNP_VERSION_MINOR
 #	define UPNP_VERSION_MINOR 0
 #endif
 
 /** Patch version of the library */
-#define UPNP_VERSION_PATCH 1
+#define UPNP_VERSION_PATCH 4
 #ifndef UPNP_VERSION_PATCH
 #	define UPNP_VERSION_PATCH 0
 #endif
@@ -64,7 +64,7 @@
  * Large file support
  ***************************************************************************/
 
-/* #undef UPNP_LARGEFILE_SENSITIVE */
+#define UPNP_LARGEFILE_SENSITIVE 1
 
 /***************************************************************************
  * Library optional features
@@ -121,14 +121,10 @@
 
 /** Defined to 1 if the library has been compiled to use blocking TCP socket
  * calls (i.e. configure --enable_blocking_tcp_connections) */
-#define UPNP_ENABLE_BLOCKING_TCP_CONNECTIONS 1
-
-/** Defined to 1 if the library has been compiled to support filesystem writes
- * on POST (i.e. configure --enable-postwrite) */
-/* #undef UPNP_ENABLE_POST_WRITE */
+/* #undef UPNP_ENABLE_BLOCKING_TCP_CONNECTIONS */
 
 /** Defined to 1 if the library has been compiled bind the miniserver socket
  * with SO_REUSEADDR (i.e. configure --enable_reuseaddr) */
-/* #undef UPNP_MINISERVER_REUSEADDR */
+#define UPNP_MINISERVER_REUSEADDR 1
 
 #endif /* UPNP_CONFIG_H */
